import { Contracts, ExtractDto } from "ts-extractor";
import { LogLevel } from "simplr-logger";
import { Contracts as MarkdownContracts } from "@simplrjs/markdown";
import { ApiItemReference } from "./contracts/api-item-reference";
import { ApiDefinitionKindAdditional, PluginResultData, Plugin, PluginConstructor } from "./contracts/plugin";
import { ApiDefinitions } from "./api-items/api-definition-list";
import { ApiTypes } from "./api-items/api-type-list";
export declare namespace GeneratorHelpers {
    /**
     * Checks if object has `TsDocsGenPlugin` static function.
     */
    function IsPluginClass(arg: any): arg is PluginConstructor;
    /**
     * Resolves plugins from given file.
     * @param file Plugin name or path to plugin.
     */
    function ResolvePlugin(file: string): Promise<Plugin[]>;
    function SerializeApiDefinition<TKind extends Contracts.ApiBaseDefinition>(extractedData: ExtractDto, apiItem: TKind, reference: ApiItemReference): ApiDefinitions;
    function SerializeApiType(extractedData: ExtractDto, apiType: Contracts.ApiType): ApiTypes;
    enum JSDocTags {
        Private = "private",
        Beta = "beta",
        Deprecated = "deprecated",
        Internal = "internal",
        Summary = "summary",
    }
    const MARKDOWN_EXT = ".md";
    const ApiDefinitionKind: typeof ApiDefinitionKindAdditional & typeof Contracts.ApiDefinitionKind;
    const DEFAULT_CODE_OPTIONS: {
        lang: string;
    };
    const DEFAULT_TABLE_OPTIONS: MarkdownContracts.TableOptions;
    function GetApiDefinitionKind(): typeof Contracts.ApiDefinitionKind & typeof ApiDefinitionKindAdditional;
    function GetApiItemReferences(extractedData: ExtractDto, itemsReference: Contracts.ApiItemReference[]): ApiItemReference[];
    function LogWithApiItemPosition(logLevel: LogLevel, apiItem: Contracts.ApiBaseDefinition | Contracts.ApiBaseType, ...message: string[]): void;
    function StandardizePath(pathString: string): string;
    function IsApiItemKind<TKindDto extends Contracts.ApiDefinition>(itemKind: Contracts.ApiDefinitionKind, apiItem: Contracts.ApiDefinition): apiItem is TKindDto;
    function MergePluginResultData<T extends PluginResultData>(a: T, b: Partial<PluginResultData> | undefined): T;
    function GetDefaultPluginResultData<TKind = Contracts.ApiDefinition>(): PluginResultData<TKind>;
    function Tab(size?: number): string;
    function EnsureFullStop(sentence: string, punctuationMark?: string): string;
}
